from command_parser.option import Option
from command_parser import logger


class Value(Option):
    def __init__(
        self,
        name: str,
        default: str,
        single_char: str | None = None,
        allowlist: list[str] | None = None,
    ) -> None:
        super(Value, self).__init__(name, single_char)
        self.value = default
        if allowlist is None:
            logger.debug(
                _("every values is accepted for {option}").format(
                    option = self.name,
                )
            )
        else:
            logger.debug(
                _(
                    "only some values is accepted for {option}".format(
                        option = self.name
                    )
                )
            )
        self.allowlist = allowlist

    def apply(self, value: str) -> None:
        """
        Give a value to the option
        """
        if self.allowlist is None:
            self.value = value
        else:
            if value in self.allowlist:
                self.value = value
            else:
                raise ValueError(
                    _(
                        "{value} is not an accepted value for the "
                        + "option {option}"
                    ).format(
                        value = value,
                        option = self.name,
                    )
                )
